#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_POSMAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_POSMAX_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/posmax.hpp>

#endif
